@@ -31,7 +31,7 @@ GetOptions(\%options, qw(
     tradeName=s
     q=s
     rsin=s
-    rsinWorkaround
+    pure_rsin
 ));
 
 if ($options{help}) {
@@ -52,8 +52,8 @@ if ($api_key) {
     use WebService::KvKAPI;
     $api = WebService::KvKAPI->new(
         api_key => $api_key,
-        $options{rsinWorkaround}
-        ? (rsin_workaround => $options{rsinWorkaround})
+        $options{pure_rsin}
+        ? (pure_rsin => $options{pure_rsin})
         : (),
     );
 }
@@ -63,8 +63,8 @@ else {
 
     $api = WebService::KvKAPI::Spoof->new(
         api_key => 'spoofmode',
-        $options{rsinWorkaround}
-        ? (rsin_workaround => $options{rsinWorkaround})
+        $options{pure_rsin}
+        ? (pure_rsin => $options{pure_rsin})
         : (),
     );
 }
@@ -91,7 +91,7 @@ query_kvk.pl - Query the Dutch Chamber of Commerce via the CLI
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
