@@ -6,7 +6,7 @@ use Moo;
 # This code has an EUPL license. Please see the LICENSE file in this repo for
 # more information.
 
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 use Carp;
 use OpenAPI::Client 0.17;
@@ -37,7 +37,7 @@ has api_host => (
     predicate => 'has_api_host',
 );
 
-has rsin_workaround => (
+has pure_rsin => (
     is        => 'ro',
     isa       => Bool,
 );
@@ -142,7 +142,7 @@ sub _rsin_workaround {
     # this to work, but we now have some method that does what we expect the
     # API to do until the KvK applies the fix on their end.
 
-    return $results unless $self->rsin_workaround;
+    return $results if $self->pure_rsin;
     return $results unless defined $params->{rsin};
     my $rsin = delete $params->{rsin};
 
@@ -164,7 +164,7 @@ sub _rsin_workaround {
 around search => sub {
     my ($orig, $self, %params) = @_;
 
-    return $self->$orig(%params) unless $self->rsin_workaround;
+    return $self->$orig(%params) if $self->pure_rsin;
 
     my $results = $self->$orig(%params);
     return $results unless defined $params{rsin};
@@ -211,7 +211,7 @@ WebService::KvKAPI - Query the Dutch Chamber of Commerence (KvK) API
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 AUTHOR
 
